==> haskell-servant-client-0.20.3.0-55.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-FWrlmoCIyRJ3QI0iq54aUU
key:                  servant-client-0.20.3.0-FWrlmoCIyRJ3QI0iq54aUU
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  fe00ea5db28dbac62a1a594358c2457f
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-FWrlmoCIyRJ3QI0iq54aUU
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
    http-media-0.8.1.1-IVN9WTR9Vpq260gzanGeUu
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    kan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    servant-0.20.3.0-FMI4LG4x1t4Dir4ovtxFzm
    servant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20.3.0-58-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-H9kkBZ4IV3U4OeAaTOKfNI
key:                  servant-client-0.20.3.0-H9kkBZ4IV3U4OeAaTOKfNI
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  c0f3c7ea19f1ee682c92267836be1618
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-H9kkBZ4IV3U4OeAaTOKfNI
depends:
    base-4.18.2.1 base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-media-0.8.1.1-ESBCw4Dvl5R7GQFVDBq0Rc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    kan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2 mtl-2.3.1
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    servant-0.20.3.0-EGizVGIAZ794yRWvR5V6rz
    servant-client-core-0.20.3.0-IG567hdFs9P773jrRHbW0f stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
